searchData={"items":[{"type":"module","title":"Baobab","doc":"Baobab is an Elixir implementation of the\n[Bamboo](https://github.com/AljoschaMeyer/bamboo) append-only log.\n\nIt is fairly opinionated about the DETS persistence of the logs.\nThey are considered to be a spool of the logs as retreived.\n\nConsumers of this library may wish to place a local copy of the logs in\na store with better indexing and query properties.\n\n#","ref":"Baobab.html"},{"type":"module","title":"Configuration - Baobab","doc":"config :baobab, spool_dir: \"/tmp\"\n\n#","ref":"Baobab.html#module-configuration"},{"type":"module","title":"Options - Baobab","doc":"- `format`: `:entry` or `:binary`, default: `:entry`\n- `log_id`: the author's log identifier, default `0`\n- `clump_id`: the bamboo clump with which associated, default: `\"default\"`\n- `revalidate`: confirm the store contents are unchanged, default: `false`\n- `replace`: rewrite log contents even if it exists, default: `false`","ref":"Baobab.html#module-options"},{"type":"function","title":"Baobab.all_entries/1","doc":"A list of all {author, log_id, seqnum} tuples in the configured store","ref":"Baobab.html#all_entries/1"},{"type":"function","title":"Baobab.all_seqnum/2","doc":"Retrieve the list of sequence numbers on a particular log identified by the\nauthor key and log number","ref":"Baobab.html#all_seqnum/2"},{"type":"function","title":"Baobab.append_log/3","doc":"Create and store a new log entry for a stored identity","ref":"Baobab.html#append_log/3"},{"type":"function","title":"Baobab.clumps/0","doc":"Retrieve a list of all available clumps","ref":"Baobab.html#clumps/0"},{"type":"function","title":"Baobab.compact/2","doc":"Compact log contents to only items in the certificate pool for\nthe latest entry.  This allows validation while reducing space used","ref":"Baobab.html#compact/2"},{"type":"function","title":"Baobab.create_clump/1","doc":"Create a clump","ref":"Baobab.html#create_clump/1"},{"type":"function","title":"Baobab.drop_clump/1","doc":"Drop a clump","ref":"Baobab.html#drop_clump/1"},{"type":"function","title":"Baobab.full_log/2","doc":"Retrieve all available entries in a particular log","ref":"Baobab.html#full_log/2"},{"type":"function","title":"Baobab.log_at/3","doc":"Retrieve an author log at a particular sequence number.\nIncludes the available certificate pool for its verification.\n\nUsing `:max` as the sequence number will use the latest","ref":"Baobab.html#log_at/3"},{"type":"function","title":"Baobab.log_entry/3","doc":"Retreive a paticular entry by author and sequence number.\n\n`:max` for the sequence number retrieves the latest known entry","ref":"Baobab.html#log_entry/3"},{"type":"function","title":"Baobab.log_range/3","doc":"Retrieve all available author log entries over a specified range: `{first, last}`.","ref":"Baobab.html#log_range/3"},{"type":"function","title":"Baobab.max_seqnum/2","doc":"Retrieve the latest sequence number on a particular log identified by the\nauthor key and log number","ref":"Baobab.html#max_seqnum/2"},{"type":"function","title":"Baobab.optvals/3","doc":"","ref":"Baobab.html#optvals/3"},{"type":"function","title":"Baobab.purge/2","doc":"Purges a given log.\n\n`:all` may be specified for `author` and/or the `log_id` option.\nSpecifying both effectively clears the entire store.\n\nReturns `stored_info/0`","ref":"Baobab.html#purge/2"},{"type":"function","title":"Examples - Baobab.purge/2","doc":"iex> Baobab.purge(:all, log_id: :all)\n[]","ref":"Baobab.html#purge/2-examples"},{"type":"function","title":"Baobab.stored_info/1","doc":"A list of {author, log_id, max_seqnum} tuples in the configured store","ref":"Baobab.html#stored_info/1"},{"type":"module","title":"Baobab.ClumpMeta","doc":"Functions for interacting with clump metadata\nMay be useful between consumers to communicate intent","ref":"Baobab.ClumpMeta.html"},{"type":"function","title":"Baobab.ClumpMeta.block/2","doc":"Create a block of a given type:\n\n- author: 32 byte-raw or 43-byte base62-encoded value\n- log_id: 64 bit unsigned integer\n- log_spec: `{author, log_id}`\n\nReturns the current block list","ref":"Baobab.ClumpMeta.html#block/2"},{"type":"function","title":"Baobab.ClumpMeta.block/3","doc":"","ref":"Baobab.ClumpMeta.html#block/3"},{"type":"function","title":"Baobab.ClumpMeta.blocked?/2","doc":"Returns a boolean indicating whether the supplied spec is blocked on the supplied clump\n\nIncludes the specifications from `block/2` and `{author, log_id, seq_num}`","ref":"Baobab.ClumpMeta.html#blocked?/2"},{"type":"function","title":"Baobab.ClumpMeta.blocks_list/1","doc":"Lists current blocks on the supplied clump_id","ref":"Baobab.ClumpMeta.html#blocks_list/1"},{"type":"function","title":"Baobab.ClumpMeta.filter_blocked/2","doc":"Filter out blocked clump logs from a supplied list of entry\ntuples ({`author`, `log_id`, `seq_num`})","ref":"Baobab.ClumpMeta.html#filter_blocked/2"},{"type":"function","title":"Baobab.ClumpMeta.unblock/2","doc":"Remove an extant block specified as per `block/2`\n\nReturns the current block list","ref":"Baobab.ClumpMeta.html#unblock/2"},{"type":"module","title":"Baobab.Entry","doc":"A struct representing a Baobab entry","ref":"Baobab.Entry.html"},{"type":"module","title":"Baobab.Entry.Validator","doc":"Validation of `Baobab.Entry` structs","ref":"Baobab.Entry.Validator.html"},{"type":"function","title":"Baobab.Entry.Validator.validate/2","doc":"Validate a `Baobab.Entry` struct relative to the provided clump_id\n\nIncludes validation of its available certificate pool","ref":"Baobab.Entry.Validator.html#validate/2"},{"type":"function","title":"Baobab.Entry.Validator.validate_backlink/2","doc":"Validate the `backlink` field of a `Baobab.Entry` relative to the provided clump","ref":"Baobab.Entry.Validator.html#validate_backlink/2"},{"type":"function","title":"Baobab.Entry.Validator.validate_entry/2","doc":"Validate a `Baobab.Entry` without full certificate pool verification.\n\nConfirms:\n  - Signature\n  - Payload hash\n  - Backlink\n  - Lipmaalink\n\n  Relative to the provided `clump_id`","ref":"Baobab.Entry.Validator.html#validate_entry/2"},{"type":"function","title":"Baobab.Entry.Validator.validate_lipmaalink/3","doc":"Validate the `lipmaalink` field of a `Baobab.Entry` relative to the provided clump_id","ref":"Baobab.Entry.Validator.html#validate_lipmaalink/3"},{"type":"function","title":"Baobab.Entry.Validator.validate_payload_hash/1","doc":"Validate the `payload_hash` field of a `Baobab.Entry`","ref":"Baobab.Entry.Validator.html#validate_payload_hash/1"},{"type":"function","title":"Baobab.Entry.Validator.validate_sig/1","doc":"Validate the `sig` field of a `Baobab.Entry`","ref":"Baobab.Entry.Validator.html#validate_sig/1"},{"type":"module","title":"Baobab.Identity","doc":"Functions related too Baobab identity (keypair) handling","ref":"Baobab.Identity.html"},{"type":"function","title":"Baobab.Identity.as_base62/1","doc":"Resolve an identity to its Base62 representation\n\nAttempts to resolve `~short` using stored logs","ref":"Baobab.Identity.html#as_base62/1"},{"type":"function","title":"Baobab.Identity.create/2","doc":"Create and store a new identity string\n\nAn optional secret key to be associated with the identity may provided, either\nraw or base62 encoded. The public key will be derived therefrom.","ref":"Baobab.Identity.html#create/2"},{"type":"function","title":"Baobab.Identity.drop/1","doc":"Drop a stored identity. `Baobab` will be unable to recover keys\n(notably `:secret` keys) destroyed herewith.","ref":"Baobab.Identity.html#drop/1"},{"type":"function","title":"Baobab.Identity.key/2","doc":"Retrieve the key for a stored identity.\n\nCan be either the `:public` or `:secret` key","ref":"Baobab.Identity.html#key/2"},{"type":"function","title":"Baobab.Identity.list/0","doc":"List all known identities with their base62 public key representation","ref":"Baobab.Identity.html#list/0"},{"type":"function","title":"Baobab.Identity.rename/2","doc":"Rename an extant identity leaving its keys intact.","ref":"Baobab.Identity.html#rename/2"},{"type":"module","title":"Baobab.Interchange","doc":"Functions related to the interchange of Bamboo data with\nother Bamboo sources","ref":"Baobab.Interchange.html"},{"type":"function","title":"Baobab.Interchange.export_store/1","doc":"Export full store contents to the provided directory\n\nProduces:\n  - JSON keyfiles for each identity\n  - Per clump directories containing\n    - a file for each author, `log_id` pair\n    - a JSON metadata file","ref":"Baobab.Interchange.html#export_store/1"},{"type":"function","title":"Baobab.Interchange.import_binaries/2","doc":"Import and store a list of log entries from their binary format.","ref":"Baobab.Interchange.html#import_binaries/2"},{"type":"function","title":"Baobab.Interchange.import_store/1","doc":"Import a bamboo store\n\nAt present this only handles an exported directory as produced by `export_store/1`","ref":"Baobab.Interchange.html#import_store/1"},{"type":"module","title":"Baobab.Persistence","doc":"Functions related to Baobab values persistence","ref":"Baobab.Persistence.html"},{"type":"function","title":"Baobab.Persistence.action/4","doc":"Interact with a Baobab persistence mechanism\n\nActions closely mirror the underlying `dets` at present","ref":"Baobab.Persistence.html#action/4"},{"type":"function","title":"Baobab.Persistence.compact/3","doc":"","ref":"Baobab.Persistence.html#compact/3"},{"type":"function","title":"Baobab.Persistence.content/5","doc":"Deal with the peristed bamboo content","ref":"Baobab.Persistence.html#content/5"},{"type":"function","title":"Baobab.Persistence.current_hash/2","doc":"Retrieve the current hash of the `:content` or `:identity` store.\n\nNo information should be gleaned from any particular hash beyond whether\nthe contents have changed since a previous check.","ref":"Baobab.Persistence.html#current_hash/2"},{"type":"function","title":"Baobab.Persistence.current_stored_info/1","doc":"Retrieve the current stored info which is the max entry for each\nstored log","ref":"Baobab.Persistence.html#current_stored_info/1"},{"type":"function","title":"Baobab.Persistence.current_value/2","doc":"Retrieve the current value of the `:content` or `:identity` store.\n\nNo information should be gleaned from any particular hash beyond whether\nthe contents have changed since a previous check.","ref":"Baobab.Persistence.html#current_value/2"}],"content_type":"text/markdown"}